@@ -1,4 +1,4 @@
-/*  $Id: xfce_theme_draw.c,v 1.14 2004/11/27 16:19:51 olivier Exp $
+/*  $Id: xfce_theme_draw.c,v 1.20.2.1 2005/03/09 21:28:49 olivier Exp $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -228,7 +228,7 @@ static void xfce_fill_background(GtkStyle * style, GdkWindow * window, GtkStateT
                 }
                 break;
         }
-        if (state_type == GTK_STATE_ACTIVE)
+        if ((state_type == GTK_STATE_ACTIVE) || (DETAIL("trough")))
         {
             shade_start = MIN (XFCE_RC_STYLE(style->rc_style)->shade_start, XFCE_RC_STYLE(style->rc_style)->shade_end);
             shade_end = MAX (XFCE_RC_STYLE(style->rc_style)->shade_start, XFCE_RC_STYLE(style->rc_style)->shade_end);
@@ -579,70 +579,63 @@ static void draw_shadow(GtkStyle * style, GdkWindow * window, GtkStateType state
         case GTK_SHADOW_IN:
             if(XFCE_RC_STYLE(style->rc_style)->smooth_edge)
             {
-                if(DETAIL("hscrollbar") || DETAIL("vscrollbar") || DETAIL("trough"))
+                if(DETAIL("trough"))
                 {
-                    if ((xt > 1) && (yt > 1))
-                    {
-                        gdk_draw_line(window, style->dark_gc[state_type], x, y, x + width - 2, y);
-                        gdk_draw_line(window, style->dark_gc[state_type], x, y, x, y + height - 2);
+                    gdk_draw_line(window, style->bg_gc[GTK_STATE_ACTIVE], x, y, x + width - 1, y);
+                    gdk_draw_line(window, style->bg_gc[GTK_STATE_ACTIVE], x, y, x, y + height - 1);
 
-                        gdk_draw_line(window, style->dark_gc[state_type], x, y + height - 1, x + width - 1, y + height - 1);
-                        gdk_draw_line(window, style->dark_gc[state_type], x + width - 1, y, x + width - 1, y + height - 1);
+                    gdk_draw_line(window, style->bg_gc[GTK_STATE_ACTIVE], x + 1, y + height - 1, x + width - 1, y + height - 1);
+                    gdk_draw_line(window, style->bg_gc[GTK_STATE_ACTIVE], x + width - 1, y + 1, x + width - 1, y + height - 1);
 
-                        gdk_draw_line(window, style->dark_gc[state_type], x + 1, y + 1, x + width - 2, y + 1);
-                        gdk_draw_line(window, style->dark_gc[state_type], x + 1, y + 1, x + 1, y + height - 2);
-
-                        gdk_draw_line(window, style->light_gc[state_type], x + 2, y + height - 2, x + width - 2, y + height - 2);
-                        gdk_draw_line(window, style->light_gc[state_type], x + width - 2, y + 2, x + width - 2, y + height - 2);
-                    }
-                    else if ((xt > 0) && (yt > 0))
-                    {
-                        gdk_draw_line(window, style->dark_gc[state_type], x, y, x + width - 1, y);
-                        gdk_draw_line(window, style->dark_gc[state_type], x, y, x, y + height - 1);
-
-                        gdk_draw_line(window, style->light_gc[state_type], x, y + height - 1, x + width - 1, y + height - 1);
-                        gdk_draw_line(window, style->light_gc[state_type], x + width - 1, y, x + width - 1, y + height - 1);
-                    }
+                    gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x, y);
+                    gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x + width - 1, y);
+                    gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x, y + height - 1);
+                    gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x + width - 1, y + height - 1);
                 }
-                else
+                else if ((xt > 1) && (yt > 1))
                 {
-                    if ((xt > 1) && (yt > 1))
-                    {
-                        gdk_draw_line(window, style->dark_gc[state_type], x + 1, y, x + width - 2, y);
-                        gdk_draw_line(window, style->dark_gc[state_type], x, y + 1, x, y + height - 2);
+                    gdk_draw_line(window, style->dark_gc[state_type], x + 1, y, x + width - 2, y);
+                    gdk_draw_line(window, style->dark_gc[state_type], x, y + 1, x, y + height - 2);
 
-                        gdk_draw_line(window, style->dark_gc[state_type], x + 1, y + height - 1, x + width - 2, y + height - 1);
-                        gdk_draw_line(window, style->dark_gc[state_type], x + width - 1, y + 1, x + width - 1, y + height - 2);
+                    gdk_draw_line(window, style->dark_gc[state_type], x + 1, y + height - 1, x + width - 2, y + height - 1);
+                    gdk_draw_line(window, style->dark_gc[state_type], x + width - 1, y + 1, x + width - 1, y + height - 2);
 
-                        gdk_draw_line(window, style->mid_gc[state_type], x + 1, y + 1, x + width - 2, y + 1);
-                        gdk_draw_line(window, style->mid_gc[state_type], x + 1, y + 1, x + 1, y + height - 2);
+                    gdk_draw_line(window, style->mid_gc[state_type], x + 1, y + 1, x + width - 2, y + 1);
+                    gdk_draw_line(window, style->mid_gc[state_type], x + 1, y + 1, x + 1, y + height - 2);
 
-                        gdk_draw_line(window, style->light_gc[state_type], x + 2, y + height - 2, x + width - 2, y + height - 2);
-                        gdk_draw_line(window, style->light_gc[state_type], x + width - 2, y + 2, x + width - 2, y + height - 2);
+                    gdk_draw_line(window, style->light_gc[state_type], x + 2, y + height - 2, x + width - 2, y + height - 2);
+                    gdk_draw_line(window, style->light_gc[state_type], x + width - 2, y + 2, x + width - 2, y + height - 2);
 
-                        gdk_draw_point(window, style->mid_gc[state_type], x, y);
-                        gdk_draw_point(window, style->mid_gc[state_type], x + width - 1, y);
-                        gdk_draw_point(window, style->mid_gc[state_type], x, y + height - 1);
-                        gdk_draw_point(window, style->mid_gc[state_type], x + width - 1, y + height - 1);
-                    }
-                    else if ((xt > 0) && (yt > 0))
-                    {
-                        gdk_draw_line(window, style->dark_gc[state_type], x + 1, y, x + width - 1, y);
-                        gdk_draw_line(window, style->dark_gc[state_type], x, y + 1, x, y + height - 1);
+                    gdk_draw_point(window, style->mid_gc[state_type], x, y);
+                    gdk_draw_point(window, style->mid_gc[state_type], x + width - 1, y);
+                    gdk_draw_point(window, style->mid_gc[state_type], x, y + height - 1);
+                    gdk_draw_point(window, style->mid_gc[state_type], x + width - 1, y + height - 1);
+                }
+                else if ((xt > 0) && (yt > 0))
+                {
+                    gdk_draw_line(window, style->dark_gc[state_type], x + 1, y, x + width - 1, y);
+                    gdk_draw_line(window, style->dark_gc[state_type], x, y + 1, x, y + height - 1);
 
-                        gdk_draw_line(window, style->light_gc[state_type], x + 1, y + height - 1, x + width - 1, y + height - 1);
-                        gdk_draw_line(window, style->light_gc[state_type], x + width - 1, y + 1, x + width - 1, y + height - 1);
+                    gdk_draw_line(window, style->light_gc[state_type], x + 1, y + height - 1, x + width - 1, y + height - 1);
+                    gdk_draw_line(window, style->light_gc[state_type], x + width - 1, y + 1, x + width - 1, y + height - 1);
 
-                        gdk_draw_point(window, style->mid_gc[state_type], x, y);
-                        gdk_draw_point(window, style->mid_gc[state_type], x + width - 1, y);
-                        gdk_draw_point(window, style->mid_gc[state_type], x, y + height - 1);
-                        gdk_draw_point(window, style->mid_gc[state_type], x + width - 1, y + height - 1);
-                    }
+                    gdk_draw_point(window, style->mid_gc[state_type], x, y);
+                    gdk_draw_point(window, style->mid_gc[state_type], x + width - 1, y);
+                    gdk_draw_point(window, style->mid_gc[state_type], x, y + height - 1);
+                    gdk_draw_point(window, style->mid_gc[state_type], x + width - 1, y + height - 1);
                 }
             }
             else
             {
-                if ((xt > 1) && (yt > 1))
+                if(DETAIL("trough"))
+                {
+                    gdk_draw_line(window, style->dark_gc[GTK_STATE_ACTIVE], x, y, x + width - 1, y);
+                    gdk_draw_line(window, style->dark_gc[GTK_STATE_ACTIVE], x, y, x, y + height - 1);
+
+                    gdk_draw_line(window, style->dark_gc[GTK_STATE_ACTIVE], x + 1, y + height - 1, x + width - 1, y + height - 1);
+                    gdk_draw_line(window, style->dark_gc[GTK_STATE_ACTIVE], x + width - 1, y + 1, x + width - 1, y + height - 1);
+                }
+                else if ((xt > 1) && (yt > 1))
                 {
                     gdk_draw_line(window, style->dark_gc[state_type], x, y, x + width - 1, y);
                     gdk_draw_line(window, style->dark_gc[state_type], x, y, x, y + height - 1);
@@ -673,7 +666,20 @@ static void draw_shadow(GtkStyle * style, GdkWindow * window, GtkStateType state
                 {
                     /* Do nothing */
                 }
-                else if(DETAIL("vscrollbar") || DETAIL("hscrollbar") || DETAIL("slider") || DETAIL("vscale") || DETAIL("hscale"))
+                else if (DETAIL("bar"))
+                {
+                    gdk_draw_line(window, style->dark_gc[state_type], x, y, x + width - 1, y);
+                    gdk_draw_line(window, style->dark_gc[state_type], x, y, x, y + height - 1);
+
+                    gdk_draw_line(window, style->dark_gc[state_type], x + 1, y + height - 1, x + width - 1, y + height - 1);
+                    gdk_draw_line(window, style->dark_gc[state_type], x + width - 1, y + 1, x + width - 1, y + height - 1);
+
+                    gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x, y);
+                    gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x + width - 1, y);
+                    gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x, y + height - 1);
+                    gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x + width - 1, y + height - 1);
+                }
+                else if(DETAIL("vscrollbar") || DETAIL("hscrollbar") || DETAIL("bar") || DETAIL("slider") || DETAIL("vscale") || DETAIL("hscale"))
                 {
                     if ((xt > 1) && (yt > 1))
                     {
